@@ -121,11 +121,6 @@ test_that("str works", {
   str(set_units(1/1:3, m/s))
 })
 
-test_that("onload/unload work", {
-  units:::.onUnLoad()
-  units:::.onLoad()
-})
-
 test_that("deprecations work", {
   expect_warning(parse_unit("m"))
 })
